@@ -1,9 +1,10 @@
 package Chemistry::Pattern::Atom;
-$VERSION = '0.15';
+$VERSION = '0.26';
+# $Id: Atom.pm,v 1.11 2005/05/16 22:08:15 itubert Exp $
 
 =head1 NAME
 
-Chemistry::Pattern::Atom
+Chemistry::Pattern::Atom - An atom that knows how to match
 
 =head1 SYNOPSIS
 
@@ -82,7 +83,7 @@ Chemistry::Obj::accessor('map_to');
 
 =head1 VERSION
 
-0.15
+0.26
 
 =head1 SEE ALSO
 
@@ -92,12 +93,12 @@ The PerlMol website L<http://www.perlmol.org/>
 
 =head1 AUTHOR
 
-Ivan Tubert E<lt>itub@cpan.orgE<gt>
+Ivan Tubert-Brohman E<lt>itub@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2004 Ivan Tubert. All rights reserved. This program is free
-software; you can redistribute it and/or modify it under the same terms as
+Copyright (c) 2005 Ivan Tubert-Brohman. All rights reserved. This program is
+free software; you can redistribute it and/or modify it under the same terms as
 Perl itself.
 
 =cut
